@@ -3,7 +3,7 @@ package core
 import (
 	_ "embed"
 	"fmt"
-	"io/ioutil"
+	"os"
 	"path/filepath"
 )
 
@@ -12,7 +12,7 @@ var CONFIG_MAN []byte
 
 func GenManPages(dir string) error {
 	manPath := filepath.Join(dir, "sake.1")
-	err := ioutil.WriteFile(manPath, CONFIG_MAN, 0644)
+	err := os.WriteFile(manPath, CONFIG_MAN, 0644)
 	CheckIfError(err)
 
 	fmt.Printf("Created %s\n", manPath)
